summaryrefslogtreecommitdiffstats
path: root/kmail/kmkernel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmkernel.cpp')
-rw-r--r--kmail/kmkernel.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmkernel.cpp b/kmail/kmkernel.cpp
index 1761a762..4ca2440c 100644
--- a/kmail/kmkernel.cpp
+++ b/kmail/kmkernel.cpp
@@ -132,7 +132,7 @@ KMKernel::KMKernel (TQObject *parent, const char *name) :
// make sure that we check for config updates before doing anything else
KMKernel::config();
// this shares the kmailrc parsing too (via KSharedConfig), and reads values from it
// so better do it here, than in some code where changing the group of config()
// would be unexpected
GlobalSettings::self();
@@ -2291,7 +2291,7 @@ TDEConfig* KMKernel::config()
assert(mySelf);
if (!mySelf->mConfig)
{
- mySelf->mConfig = KSharedConfig::openConfig( "kmailrc" );
+ mySelf->mConfig = TDESharedConfig::openConfig( "kmailrc" );
// Check that all updates have been run on the config file:
KMail::checkConfigUpdates();
}
@@ -132,7 +132,7 @@ KMKernel::KMKernel (TQObject *parent, const char *name) :
// make sure that we check for config updates before doing anything else
KMKernel::config();
- // this shares the kmailrc parsing too (via KSharedConfig), and reads values from it
+ // this shares the kmailrc parsing too (via TDESharedConfig), and reads values from it
// so better do it here, than in some code where changing the group of config()
// would be unexpected